package com.yeejoin.equipmanage.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import java.util.List;
import java.util.Map;

/**
 *
 * 四横八纵应急模块接口服务类
 *
 *
 */
public interface IEmergencyService {
    /**
     * @return
     */
    List<Map<String, Object>> getSystemState(String bizOrgCode);

    /**
     * @return
     */
    List<Map<String, Object>> getCAFSWaterTankInfo(String bizOrgCode);

    Map<String, Object> emergencyMaterials();

    Page<Map<String, Object>> emergencyMaterialsDetails(Page<Map<String, Object>> page, String bizOrgCode);

    Page<Map<String, Object>> selectFireMonitor(Page<Map<String, Object>> page, String bizOrgCode,String code);

    Page<Map<String, Object>> selectFoamTank(Page<Map<String, Object>> page, String bizOrgCode);

    Page<Map<String, Object>> selectOilDrainage(Page<Map<String, Object>> page, String bizOrgCode, String code);

    Page<Map<String, Object>> selectPressureFlow(Page<Map<String, Object>> page, String bizOrgCode);

    List<Map<String, Object>> selectAlarmAnalysis(String startDate, String endDate, String dataType, String date, String systemType);

    List<Map<String, Object>> selectAlarmAnalysisCount(String systemType, String startDate, String endDate);

    Map<String, Object> systemAndCar();

    List<Map<String, Object>> selectFireCannonAlarmAnalysisPie(String startDate, String endDate, String systemType);

    List<Map<String, Object>> waterSystemAlarmAnalysisPie(String startDate, String endDate, String systemType);

    List<Map<String, Object>> waterSystemAlarmAnalysis(String startDate, String endDate, String dataType, String date, String systemType);

    List<Map<String, Object>> fireCannonSystemAlarmAnalysis(String startDate, String endDate, String dataType, String date, String systemType);


}
